#
# spec file for package ghc-quickcheck-instances
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name quickcheck-instances
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.3.30
Release:        bp156.1.1
Summary:        Common quickcheck instances
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/1.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-OneTuple-devel
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-array-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-case-insensitive-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-data-array-byte-devel
BuildRequires:  ghc-data-fix-devel
BuildRequires:  ghc-hashable-devel
BuildRequires:  ghc-integer-logarithms-devel
BuildRequires:  ghc-old-time-devel
BuildRequires:  ghc-primitive-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-scientific-devel
BuildRequires:  ghc-splitmix-devel
BuildRequires:  ghc-strict-devel
BuildRequires:  ghc-tagged-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-short-devel
BuildRequires:  ghc-these-devel
BuildRequires:  ghc-time-compat-devel
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-transformers-compat-devel
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-unordered-containers-devel
BuildRequires:  ghc-uuid-types-devel
BuildRequires:  ghc-vector-devel
ExcludeArch:    %{ix86}

%description
QuickCheck instances.

The goal is to supply QuickCheck instances for types provided by the Haskell
Platform.

Since all of these instances are provided as orphans, I recommend that you do
not use this library within another library module, so that you don't impose
these instances on down-stream consumers of your code.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGES

%changelog
* Sun Oct 15 2023 Peter Simons <psimons@suse.com>
- Update quickcheck-instances to version 0.3.30 revision 1.
  0.3.30
  * Improve Arbitrary UUID instance
    Previously "small" UUIDs were generated, e.g.
    ```
    00000001-0000-0001-0000-000000000001
    00000002-0000-0000-0000-000200000002
    00000004-0000-0004-0000-000400000001
    00000005-0000-0000-0000-000500000007
    00000001-0000-000d-0000-00050000000e
    ```
    but now they are uniformly random
    ```
    c4683284-bfe3-224b-29a6-1e7f11ceef65
    7bf6564d-5dcf-3e37-b13d-867085f54dae
    5b006243-0a70-9321-6594-20dde3d72112
    2d8ed56e-ed20-7258-7c1f-b46fa9b87946
    f1503184-9d3c-aacd-e9a7-36c655b70f41
    ```
  0.3.29.1
  * Support `OneTuple-0.4`
  0.3.29
  * Support `primitive-0.8`
  * Use `data-array-byte` shim package for instances for `Data.Array.Byte.ByteArray`
  0.3.28
  * Add instances for `Data.Array.Byte.ByteArray` (`base-4.17`)
  * Add instances for `Data.Primitive.ByteArray` (`primitive`)
* Sat Jan  1 2022 Peter Simons <psimons@suse.com>
- Update quickcheck-instances to version 0.3.27 revision 1.
  0.3.27
  * Add instances for `Backwards`, `Reverse` and `Lift` from `transformers`
* Tue Nov 16 2021 psimons@suse.com
- Update quickcheck-instances to version 0.3.26.1 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Nov  1 2021 psimons@suse.com
- Update quickcheck-instances to version 0.3.26.1.
  0.3.26.1
  * Support `hashable-1.4`
  0.3.26
  * Support base-4.16 / GHC-9.2
  * Add instances for `text-short`'s `ShortText` type
  * Add instances for `Solo`
  * Fix bug in `CoArbitrary (Hashed a)` instance
* Wed Jul 28 2021 psimons@suse.com
- Update quickcheck-instances to version 0.3.25.2 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Apr 26 2021 psimons@suse.com
- Add quickcheck-instances at version 0.3.25.2 revision 1.
